@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -298,7 +298,7 @@ sub _validate {
   return if ref $data and $self->{seen}{"$schema\:$data"}++;
 
   # Make sure we validate plain data and not a perl object
-  $data = $data->TO_JSON if UNIVERSAL::can($data, 'TO_JSON');
+  $data = $data->TO_JSON if Scalar::Util::blessed($data) and UNIVERSAL::can($data, 'TO_JSON');
   $type = $schema->{type} || _guess_schema_type($schema, $data);
 
   # Test base schema before allOf, anyOf or oneOf
@@ -784,7 +784,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 SYNOPSIS
 
